==> console-plugin-service-3.0-sources.jar: org/glassfish/admingui/plugin/IntegrationPointInjector.java <==

package org.glassfish.admingui.plugin;

import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.config.ConfigInjector;
import org.jvnet.hk2.config.Dom;
import org.jvnet.hk2.config.InjectionTarget;

@Service(name = "integration-point", metadata = "@content=optional,@content=datatype:java.lang.String,@content=leaf,@priority=optional,@priority=datatype:java.lang.String,@priority=leaf,@type=required,@type=datatype:java.lang.String,@type=leaf,@parentId=optional,@parentId=datatype:java.lang.String,@parentId=leaf,target=org.glassfish.admingui.plugin.IntegrationPoint,@id=required,@id=datatype:java.lang.String,@id=leaf")
@InjectionTarget(IntegrationPoint.class)
public class IntegrationPointInjector
    extends ConfigInjector<IntegrationPoint>
{


    public void inject(Dom dom, IntegrationPoint target) {
        attribute_setId(dom, target);
        attribute_setType(dom, target);
        attribute_setParentId(dom, target);
        attribute_setContent(dom, target);
        attribute_setPriority(dom, target);
    }

    public void injectAttribute(Dom dom, String name, IntegrationPoint target) {
        if ("id".equals(name)) {
            attribute_setId(dom, target);
        }
        if ("type".equals(name)) {
            attribute_setType(dom, target);
        }
        if ("parentId".equals(name)) {
            attribute_setParentId(dom, target);
        }
        if ("content".equals(name)) {
            attribute_setContent(dom, target);
        }
        if ("priority".equals(name)) {
            attribute_setPriority(dom, target);
        }
    }

    public void injectElement(Dom dom, String name, IntegrationPoint target) {
    }

    public void attribute_setId(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("id");
        target.setId(v1);
    }

    public void attribute_setType(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("type");
        target.setType(v1);
    }

    public void attribute_setParentId(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("parentId");
        if (v1 == null) {
            return ;
        }
        target.setParentId(v1);
    }

    public void attribute_setContent(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("content");
        if (v1 == null) {
            return ;
        }
        target.setContent(v1);
    }

    public void attribute_setPriority(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("priority");
        if (v1 == null) {
            return ;
        }
        target.setPriority(asInt(v1));
    }

}

==> console-plugin-service-3.1.1-b02-sources.jar: org/glassfish/admingui/plugin/IntegrationPointInjector.java <==

package org.glassfish.admingui.plugin;

import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.config.ConfigInjector;
import org.jvnet.hk2.config.Dom;
import org.jvnet.hk2.config.InjectionTarget;

@Service(name = "integration-point", metadata = "target=org.glassfish.admingui.plugin.IntegrationPoint,@id=required,@id=datatype:java.lang.String,@id=leaf,@type=required,@type=datatype:java.lang.String,@type=leaf,@parentId=optional,@parentId=datatype:java.lang.String,@parentId=leaf,@content=optional,@content=datatype:java.lang.String,@content=leaf,@priority=optional,@priority=datatype:java.lang.String,@priority=leaf")
@InjectionTarget(IntegrationPoint.class)
public class IntegrationPointInjector
    extends ConfigInjector<IntegrationPoint>
{


    public void inject(Dom dom, IntegrationPoint target) {
        attribute_setId(dom, target);
        attribute_setType(dom, target);
        attribute_setParentId(dom, target);
        attribute_setContent(dom, target);
        attribute_setPriority(dom, target);
    }

    public void injectAttribute(Dom dom, String name, IntegrationPoint target) {
        if ("id".equals(name)) {
            attribute_setId(dom, target);
        }
        if ("type".equals(name)) {
            attribute_setType(dom, target);
        }
        if ("parentId".equals(name)) {
            attribute_setParentId(dom, target);
        }
        if ("content".equals(name)) {
            attribute_setContent(dom, target);
        }
        if ("priority".equals(name)) {
            attribute_setPriority(dom, target);
        }
    }

    public void injectElement(Dom dom, String name, IntegrationPoint target) {
    }

    public void attribute_setId(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("id");
        target.setId(v1);
    }

    public void attribute_setType(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("type");
        target.setType(v1);
    }

    public void attribute_setParentId(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("parentId");
        if (v1 == null) {
            return ;
        }
        target.setParentId(v1);
    }

    public void attribute_setContent(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("content");
        if (v1 == null) {
            return ;
        }
        target.setContent(v1);
    }

    public void attribute_setPriority(Dom dom, IntegrationPoint target) {
        String v1 = dom.attribute("priority");
        if (v1 == null) {
            return ;
        }
        target.setPriority(asInt(v1));
    }

}
